();
- hucs.add(FFMPRecord.ALL);
- }
-
- for (String huc : hucs) {
-
- FFMPRecord populatedRec = populateRecord(rec, huc,
- template);
- FFMPBasinData newData = populatedRec.getBasinData(huc);
- sourceContainer.addFFMPEntry(populatedRec.getDataTime()
- .getRefTime(), source, newData, huc, siteKey);
- }
-
+ rec = populateRecord(rec, template);
+ FFMPBasinData newData = rec.getBasinData();
+ sourceContainer.addFFMPEntry(
+ rec.getDataTime().getRefTime(), source, newData,
+ siteKey);
} catch (Exception e) {
statusHandler.handle(Priority.ERROR,
"Source: " + source.getDisplayName() + " domain: "
@@ -306,19 +298,19 @@ public class FFTIProcessor {
* @return
* @throws PluginException
*/
- public static FFMPRecord populateRecord(FFMPRecord rec, String huc,
+ public static FFMPRecord populateRecord(FFMPRecord rec,
FFMPTemplates template) throws PluginException {
try {
-
+
SourceXML source = FFMPSourceConfigurationManager.getInstance()
.getSource(rec.getSourceName());
// check for gage(VGB) types, if so process as a VGB
if (source.getSourceType().equals(SOURCE_TYPE.GAGE.getSourceType())) {
- rec.retrieveVirtualMapFromDataStore(template, huc);
+ rec.retrieveVirtualMapFromDataStore(template);
} else {
- rec.retrieveMapFromDataStore(template, huc);
+ rec.retrieveMapFromDataStore(template);
}
} catch (Exception e) {
diff --git a/edexOsgi/com.raytheon.uf.edex.plugin.nwsauth/utility/common_static/base/roles/userRoles.xml b/edexOsgi/com.raytheon.uf.edex.plugin.nwsauth/utility/common_static/base/roles/userRoles.xml
index 77a61c3f3f..91752e1a0c 100644
--- a/edexOsgi/com.raytheon.uf.edex.plugin.nwsauth/utility/common_static/base/roles/userRoles.xml
+++ b/edexOsgi/com.raytheon.uf.edex.plugin.nwsauth/utility/common_static/base/roles/userRoles.xml
@@ -91,7 +91,7 @@
-
+
com.raytheon.localization.site/common_static/purge
@@ -124,7 +124,7 @@
com.raytheon.localization.site/common_static/shef
com.raytheon.localization.site/common_static/roles
com.raytheon.localization.site/common_static/datadelivery
- com.raytheon.localization.site/common_static/archive
+ com.raytheon.localization.site/common_static/archiver/purger
diff --git a/javaUtilities/com.raytheon.wes2bridge.configuration/build.xml b/javaUtilities/com.raytheon.wes2bridge.configuration/build.xml
index 8192c6495c..92309808f9 100644
--- a/javaUtilities/com.raytheon.wes2bridge.configuration/build.xml
+++ b/javaUtilities/com.raytheon.wes2bridge.configuration/build.xml
@@ -11,11 +11,11 @@
-
+
-
+
diff --git a/javaUtilities/com.raytheon.wes2bridge.manager/build.xml b/javaUtilities/com.raytheon.wes2bridge.manager/build.xml
index c9ec1c5be5..0c60037d4e 100644
--- a/javaUtilities/com.raytheon.wes2bridge.manager/build.xml
+++ b/javaUtilities/com.raytheon.wes2bridge.manager/build.xml
@@ -11,11 +11,11 @@
-
+
-
+
diff --git a/ncep/gov.noaa.nws.ncep.common.dataplugin.idft/src/gov/noaa/nws/ncep/common/dataplugin/idft/IdftRecord.java b/ncep/gov.noaa.nws.ncep.common.dataplugin.idft/src/gov/noaa/nws/ncep/common/dataplugin/idft/IdftRecord.java
index 2c0257ae40..6a98caea32 100644
--- a/ncep/gov.noaa.nws.ncep.common.dataplugin.idft/src/gov/noaa/nws/ncep/common/dataplugin/idft/IdftRecord.java
+++ b/ncep/gov.noaa.nws.ncep.common.dataplugin.idft/src/gov/noaa/nws/ncep/common/dataplugin/idft/IdftRecord.java
@@ -27,11 +27,12 @@
package gov.noaa.nws.ncep.common.dataplugin.idft;
-
import gov.noaa.nws.ncep.common.tools.IDecoderConstantsN;
import java.util.Calendar;
+import javax.persistence.Access;
+import javax.persistence.AccessType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.SequenceGenerator;
@@ -50,6 +51,22 @@ import com.raytheon.uf.common.dataplugin.annotations.DataURI;
import com.raytheon.uf.common.serialization.annotations.DynamicSerialize;
import com.raytheon.uf.common.serialization.annotations.DynamicSerializeElement;
+/**
+ *
+ *
+ *
+ *
+ * SOFTWARE HISTORY
+ *
+ * Date Ticket# Engineer Description
+ * ------------ ---------- ----------- --------------------------
+ * 07/22/2013 1977 rjpeter Added getDataURI and annotations.
+ *
+ *
+ *
+ * @author rjpeter
+ * @version 1.0
+ */
@Entity
@SequenceGenerator(initialValue = 1, name = PluginDataObject.ID_GEN, sequenceName = "idftseq")
@Table(name = "idft", uniqueConstraints = { @UniqueConstraint(columnNames = { "dataURI" }) })
@@ -57,72 +74,66 @@ import com.raytheon.uf.common.serialization.annotations.DynamicSerializeElement;
* Both refTime and forecastTime are included in the refTimeIndex since
* forecastTime is unlikely to be used.
*/
-@org.hibernate.annotations.Table(
- appliesTo = "idft",
- indexes = {
- @Index(name = "idft_refTimeIndex", columnNames = { "refTime", "forecastTime" } )
- }
-)
+@org.hibernate.annotations.Table(appliesTo = "idft", indexes = { @Index(name = "idft_refTimeIndex", columnNames = {
+ "refTime", "forecastTime" }) })
@XmlRootElement
@XmlAccessorType(XmlAccessType.NONE)
@DynamicSerialize
+public class IdftRecord extends PluginDataObject {
-public class IdftRecord extends PluginDataObject{
-
- private static final long serialVersionUID = 1L;
+ private static final long serialVersionUID = 1L;
- /** Report type */
- @Column(length=32)
- @XmlElement
+ /** Report type */
+ @Column(length = 32)
+ @XmlElement
@DataURI(position = 4)
- @DynamicSerializeElement
- private String reportType;
-
- @Column
+ @DynamicSerializeElement
+ private String reportType;
+
+ @Column
@DataURI(position = 1)
@DynamicSerializeElement
- @XmlElement
- private Calendar issueTime;
+ @XmlElement
+ private Calendar issueTime;
- @Column
+ @Column
@DataURI(position = 2)
@DynamicSerializeElement
- @XmlElement
- private Calendar validTime;
+ @XmlElement
+ private Calendar validTime;
@XmlElement
@DataURI(position = 3)
@DynamicSerializeElement
- private Integer pointNum;
+ private Integer pointNum;
@XmlElement
@DynamicSerializeElement
- private Float lat;
+ private Float lat;
@XmlElement
@DynamicSerializeElement
- private Float lon;
+ private Float lon;
@XmlElement
@DynamicSerializeElement
- private Float direction;
+ private Float direction;
@XmlElement
@DynamicSerializeElement
- private Float distanceNm;
+ private Float distanceNm;
-
- /**
+ /**
* Default Constructor
*/
public IdftRecord() {
- this.issueTime = null;
- this.validTime = null;
- this.pointNum = IDecoderConstantsN.INTEGER_MISSING;
- this.lat = IDecoderConstantsN.FLOAT_MISSING;
- this.lon = IDecoderConstantsN.FLOAT_MISSING;
- this.direction = IDecoderConstantsN.FLOAT_MISSING;
- this.distanceNm = IDecoderConstantsN.FLOAT_MISSING;
+ this.issueTime = null;
+ this.validTime = null;
+ this.pointNum = IDecoderConstantsN.INTEGER_MISSING;
+ this.lat = IDecoderConstantsN.FLOAT_MISSING;
+ this.lon = IDecoderConstantsN.FLOAT_MISSING;
+ this.direction = IDecoderConstantsN.FLOAT_MISSING;
+ this.distanceNm = IDecoderConstantsN.FLOAT_MISSING;
}
/**
@@ -140,61 +151,75 @@ public class IdftRecord extends PluginDataObject{
// TODO Auto-generated method stub
return null;
}
-
- public String getReportType() {
- return reportType;
- }
- public void setReportType(String reportType) {
- this.reportType = reportType;
- }
-
- public Calendar getIssueTime(){
- return issueTime;
- }
- public void setIssueTime(Calendar issueTime){
- this.issueTime=issueTime;
- }
-
- public Calendar getValidTime(){
- return validTime;
- }
- public void setValidTime(Calendar validTime){
- this.validTime=validTime;
- }
-
- public Integer getPointNum(){
- return pointNum;
- }
- public void setPointNum(Integer pointNum){
- this.pointNum=pointNum;
- }
-
- public float getLat(){
- return lat;
- }
- public void setLat(float latitude){
- this.lat=latitude;
- }
-
- public float getLon(){
- return lon;
- }
- public void setLon(float longitude){
- this.lon=longitude;
- }
-
- public float getDirection(){
- return direction;
- }
- public void setDirection(float direction){
- this.direction=direction;
- }
-
- public float getDistanceNm(){
- return distanceNm;
- }
- public void setDistanceNm(float distanceNm){
- this.distanceNm=distanceNm;
- }
+ public String getReportType() {
+ return reportType;
+ }
+
+ public void setReportType(String reportType) {
+ this.reportType = reportType;
+ }
+
+ public Calendar getIssueTime() {
+ return issueTime;
+ }
+
+ public void setIssueTime(Calendar issueTime) {
+ this.issueTime = issueTime;
+ }
+
+ public Calendar getValidTime() {
+ return validTime;
+ }
+
+ public void setValidTime(Calendar validTime) {
+ this.validTime = validTime;
+ }
+
+ public Integer getPointNum() {
+ return pointNum;
+ }
+
+ public void setPointNum(Integer pointNum) {
+ this.pointNum = pointNum;
+ }
+
+ public float getLat() {
+ return lat;
+ }
+
+ public void setLat(float latitude) {
+ this.lat = latitude;
+ }
+
+ public float getLon() {
+ return lon;
+ }
+
+ public void setLon(float longitude) {
+ this.lon = longitude;
+ }
+
+ public float getDirection() {
+ return direction;
+ }
+
+ public void setDirection(float direction) {
+ this.direction = direction;
+ }
+
+ public float getDistanceNm() {
+ return distanceNm;
+ }
+
+ public void setDistanceNm(float distanceNm) {
+ this.distanceNm = distanceNm;
+ }
+
+ @Override
+ @Column
+ @Access(AccessType.PROPERTY)
+ public String getDataURI() {
+ return super.getDataURI();
+ }
}
diff --git a/ncep/gov.noaa.nws.ncep.common.dataplugin.pgen/src/gov/noaa/nws/ncep/common/dataplugin/pgen/PgenRecord.java b/ncep/gov.noaa.nws.ncep.common.dataplugin.pgen/src/gov/noaa/nws/ncep/common/dataplugin/pgen/PgenRecord.java
index a5ca5b327e..c7f1b9d8c4 100644
--- a/ncep/gov.noaa.nws.ncep.common.dataplugin.pgen/src/gov/noaa/nws/ncep/common/dataplugin/pgen/PgenRecord.java
+++ b/ncep/gov.noaa.nws.ncep.common.dataplugin.pgen/src/gov/noaa/nws/ncep/common/dataplugin/pgen/PgenRecord.java
@@ -1,5 +1,7 @@
package gov.noaa.nws.ncep.common.dataplugin.pgen;
+import javax.persistence.Access;
+import javax.persistence.AccessType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.SequenceGenerator;
@@ -30,7 +32,7 @@ import com.raytheon.uf.common.serialization.annotations.DynamicSerializeElement;
* ------------ ---------- ----------- --------------------------
* Apr 22, 2013 sgilbert Initial creation
* Jun 26, 2013 bhebbard Added SequenceGenerator annotation
- *
+ * Jul 22, 2013 1977 rjpeter Added getDataURI and annotations.
*
*
* @author sgilbert
@@ -262,4 +264,10 @@ public class PgenRecord extends PersistablePluginDataObject {
return null;
}
+ @Override
+ @Column
+ @Access(AccessType.PROPERTY)
+ public String getDataURI() {
+ return super.getDataURI();
+ }
}
diff --git a/ncep/gov.noaa.nws.ncep.edex.plugin.geomag/utility/edex_static/base/distribution/geomag.xml b/ncep/gov.noaa.nws.ncep.edex.plugin.geomag/utility/edex_static/base/distribution/geomag.xml
index f7d76c13de..405e30cfe4 100644
--- a/ncep/gov.noaa.nws.ncep.edex.plugin.geomag/utility/edex_static/base/distribution/geomag.xml
+++ b/ncep/gov.noaa.nws.ncep.edex.plugin.geomag/utility/edex_static/base/distribution/geomag.xml
@@ -1,4 +1,3 @@
-
diff --git a/ncep/gov.noaa.nws.ncep.edex.plugin.nctext/res/scripts/inputFileTbl b/ncep/gov.noaa.nws.ncep.edex.plugin.nctext/res/scripts/inputFileTbl
index 58fa26148c..e758ad7229 100644
--- a/ncep/gov.noaa.nws.ncep.edex.plugin.nctext/res/scripts/inputFileTbl
+++ b/ncep/gov.noaa.nws.ncep.edex.plugin.nctext/res/scripts/inputFileTbl
@@ -38,9 +38,10 @@ HURR_LOCAL stations.tbl W $TEXT_DATA2/tropical/HLS HLS
DAY_1 day1.bull B $TEXT_DATA/spc/day1 day1
DAY_2 day2.bull B $TEXT_DATA/spc/day2 day2
DAY_3 day3.bull B $TEXT_DATA/spc/day3 day3
-DAY_1_PT day1pts.bull B $TEXT_DATA/spc/otlkpts ptsdy1
-DAY_2_PT day2pts.bull B $TEXT_DATA/spc/otlkpts ptsdy2
-DAY_3_PT day3pts.bull B $TEXT_DATA/spc/otlkpts ptsdy3
+DAY_3_8_OLK stations.tbl B $TEXT_DATA/../all_prods/forecast/land fwddy38
+DAY_1_PT day1pts.bull B $TEXT_DATA/watch_warn/tstrm_warn ptsdy1
+DAY_2_PT day2pts.bull B $TEXT_DATA/watch_warn/tstrm_warn ptsdy2
+DAY_3_PT day3pts.bull B $TEXT_DATA/watch_warn/tstrm_warn ptsdy3
WATCH_BOX watndsc.bull B $TEXT_DATA/spc/watch2 wtch2
ALL_WBOX watbox.bull B $TEXT_DATA/spc/watch watch
WATCH_NDSC watndsc.bull B $TEXT_DATA/spc/watch2 wtch2
@@ -177,4 +178,4 @@ CSPS stations.tbl W $TEXT_DATA/canada/sps sps
CWATCH stations.tbl W $TEXT_DATA/canada/warwatch warwatch
CWARNSUMM stations.tbl W $TEXT_DATA/canada/warnsumm warnsumm
COUTLOOK stations.tbl W $TEXT_DATA/canada/coutlook coutlook
-
\ No newline at end of file
+
diff --git a/ncep/gov.noaa.nws.ncep.edex.plugin.nctext/res/scripts/inputFileType.sql b/ncep/gov.noaa.nws.ncep.edex.plugin.nctext/res/scripts/inputFileType.sql
index 33aef74284..d0cc2c5f3a 100644
--- a/ncep/gov.noaa.nws.ncep.edex.plugin.nctext/res/scripts/inputFileType.sql
+++ b/ncep/gov.noaa.nws.ncep.edex.plugin.nctext/res/scripts/inputFileType.sql
@@ -176,3 +176,4 @@ INSERT INTO awips.nctext_inputfile_type VALUES (176,'sps','W');
INSERT INTO awips.nctext_inputfile_type VALUES (177,'warwatch','W');
INSERT INTO awips.nctext_inputfile_type VALUES (178,'warnsumm','W');
INSERT INTO awips.nctext_inputfile_type VALUES (179,'coutlook','W');
+INSERT INTO awips.nctext_inputfile_type VALUES (180,'fwddy38','W');
diff --git a/ncep/gov.noaa.nws.ncep.edex.plugin.nctext/src/gov/noaa/nws/ncep/edex/plugin/nctext/decoder/NctextRegexMatcher.java b/ncep/gov.noaa.nws.ncep.edex.plugin.nctext/src/gov/noaa/nws/ncep/edex/plugin/nctext/decoder/NctextRegexMatcher.java
index e8d29e7737..d669d9fa56 100644
--- a/ncep/gov.noaa.nws.ncep.edex.plugin.nctext/src/gov/noaa/nws/ncep/edex/plugin/nctext/decoder/NctextRegexMatcher.java
+++ b/ncep/gov.noaa.nws.ncep.edex.plugin.nctext/src/gov/noaa/nws/ncep/edex/plugin/nctext/decoder/NctextRegexMatcher.java
@@ -164,12 +164,14 @@ public final class NctextRegexMatcher {
//split above pattern to the following 3 patterns so matchFileRegex() can be coded in a generic way.
thisMap.put(Pattern.compile("^FXHW60 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "area");
thisMap.put(Pattern.compile("^FXPN60 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "area");
- thisMap.put(Pattern.compile("^FXPS60 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "area");
-
+ thisMap.put(Pattern.compile("^FXPS60 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "area");
thisMap.put(Pattern.compile("^...... .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*(\n|\r)FA[0-9].*"), "area"); //aviation forecasts
thisMap.put(Pattern.compile("^WWUS30 KWNS (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"),"wtch2");
thisMap.put(Pattern.compile("^FNUS21 KWNS (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"),"fwddy1");
thisMap.put(Pattern.compile("^FNUS22 KWNS (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"),"fwddy2");
+ thisMap.put(Pattern.compile("^FNUS28 KWNS (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"),"fwddy38");
+ thisMap.put(Pattern.compile("^FNUS21 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*(\n|\r)FWDDY1.*"),"fire1"); //spc uses this regex for fwddy1 also
+ thisMap.put(Pattern.compile("^FNUS22 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*(\n|\r)FWDDY2.*"),"fire2"); //spc uses this regex for fwddy2 also
thisMap.put(Pattern.compile("^WOUS64 KWNS (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "wou");
thisMap.put(Pattern.compile("^ABNT20 KNHC (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "outlk"); //clashes with TWO
thisMap.put(Pattern.compile("^ACPN50 PHFO (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "outlk");
@@ -267,14 +269,13 @@ public final class NctextRegexMatcher {
thisMap.put(Pattern.compile("^WAUS1 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "airm"); //no data to test
thisMap.put(Pattern.compile("^WAAK01 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "airm"); //no data to test
thisMap.put(Pattern.compile("^WOUS20 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "stat");
- thisMap.put(Pattern.compile("^FVXX2[0-4] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "volc");
+ thisMap.put(Pattern.compile("^FVXX2[0-7] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "volc");
thisMap.put(Pattern.compile("^FVCN0[0-4] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "volc");
thisMap.put(Pattern.compile("^FVAU0[2-4] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "volc");
thisMap.put(Pattern.compile("^ACUS4[1-5] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "storm");
thisMap.put(Pattern.compile("^FSUS02 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "srp");
thisMap.put(Pattern.compile("^ASUS01 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "sus");
thisMap.put(Pattern.compile("^FXPA00 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "expac"); //no folder for raw data in server
- thisMap.put(Pattern.compile("^FVXX2[0-7] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "vlcf"); //clashes with volc FVXX2[0-4]
thisMap.put(Pattern.compile("^ACUS48 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "day48");
thisMap.put(Pattern.compile("^FNUS31 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*(\n|\r)PFWFD1.*"), "pfwfd1");
thisMap.put(Pattern.compile("^FNUS32 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*(\n|\r)PFWFD2.*"), "pfwfd2");
@@ -288,9 +289,6 @@ public final class NctextRegexMatcher {
thisMap.put(Pattern.compile("^ACUS01 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "day1");
thisMap.put(Pattern.compile("^ACUS02 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "day2");
thisMap.put(Pattern.compile("^ACUS03 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "day3");
- thisMap.put(Pattern.compile("^WWUS01 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"),"ptsdy1"); //no data to test
- thisMap.put(Pattern.compile("^WWUS02 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"),"ptsdy2");//no data to test
- thisMap.put(Pattern.compile("^WWUS03 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"),"ptsdy3");//no data to test
thisMap.put(Pattern.compile("^WWUS20 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"),"watch");
thisMap.put(Pattern.compile("^WWUS50 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*(\n|\r)SEV[0-9].*"),"sev");
thisMap.put(Pattern.compile("^WWUS60 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*(\n|\r)SEVSPC.*"),"sevmkc");
@@ -299,8 +297,6 @@ public final class NctextRegexMatcher {
thisMap.put(Pattern.compile("^ACUS11 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"),"meso");
thisMap.put(Pattern.compile("^NWUS20 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*(\n|\r)STADTS"),"dts");
thisMap.put(Pattern.compile("^NWUS20 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"),"svr");
- thisMap.put(Pattern.compile("^FNUS21 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*(\n|\r)FWDDY1.*"),"fire1"); //spc uses this regex for fwddy1 also
- thisMap.put(Pattern.compile("^FNUS22 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*(\n|\r)FWDDY2.*"),"fire2"); //spc uses this regex for fwddy2 also
thisMap.put(Pattern.compile("^WHXX9[09] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "mdl"); // not sure if this regex is correct - no test data to verify
thisMap.put(Pattern.compile("^WHXX0[1-4] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "mdl");
thisMap.put(Pattern.compile("^URNT10 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "antreco");
@@ -341,13 +337,14 @@ public final class NctextRegexMatcher {
thisMap.put(Pattern.compile("^W[CSV]AK[01][0-9] KKCI (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "intl"); //regexes clash for intl and sgmt
thisMap.put(Pattern.compile("^W[CSV]AK[01][0-9] PHFO (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "intl"); //regexes clash for intl and sgmt
thisMap.put(Pattern.compile("^W[CSV]AK[01][0-9] PAWU (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "intl"); //regexes clash for intl and sgmt
-
-
+ thisMap.put(Pattern.compile("^WUUS01 KWNS (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "ptsdy1"); //regexes clash for convective outlook point product day1
+ thisMap.put(Pattern.compile("^WUUS02 KWNS (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "ptsdy2"); //regexes clash for convective outlook point product day2
+ thisMap.put(Pattern.compile("^WUUS03 KWNS (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "ptsdy3"); //regexes clash for convective outlook point product day3
thisMap.put(Pattern.compile("^WSUS4[012] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "conv");
thisMap.put(Pattern.compile("^W[CSV]US0[1-6] KKCI (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "sgmt");
thisMap.put(Pattern.compile("^WSUK.. .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "sgmt");
thisMap.put(Pattern.compile("^WS[^U]... .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+"), "sgmt"); //regexes clash for intl and sgmt
- thisMap.put(Pattern.compile("^FT.... .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)*TAF[A-Z]{3}(.|\r|\n)*"), "taf"); //observed TAFS
+ thisMap.put(Pattern.compile("^FT.... .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)*TAF[A-Z]{3}(.|\r|\n)*"), "taf"); //aviation TAFS
thisMap.put(Pattern.compile("^FT.... .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9])(.|\r|\n)+TAF( |\r|\n){1}(.|\r|\n)*"), "fts"); //aviation TAFS
thisMap.put(Pattern.compile("^...... KWBC (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*(\n|\r)(HSF).*"), "HSF"); //conflicts with FLN
thisMap.put(Pattern.compile("^...... PHFO (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*(\n|\r)(HSF).*"), "HSF");
diff --git a/ncep/gov.noaa.nws.ncep.edex.plugin.nctext/utility/edex_static/base/distribution/nctext.xml b/ncep/gov.noaa.nws.ncep.edex.plugin.nctext/utility/edex_static/base/distribution/nctext.xml
index 440b579cff..8b589363d3 100644
--- a/ncep/gov.noaa.nws.ncep.edex.plugin.nctext/utility/edex_static/base/distribution/nctext.xml
+++ b/ncep/gov.noaa.nws.ncep.edex.plugin.nctext/utility/edex_static/base/distribution/nctext.xml
@@ -128,14 +128,13 @@
^WAUS1 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
^WAAK01 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
^WOUS20 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
- ^FVXX2[0-4] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
^FVCN0[0-4] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
^FVAU0[2-4] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
+ ^FVXX2[0-7] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
^ACUS4[1-5] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
^FSUS02 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
^ASUS01 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
^FXPA00 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
- ^FVXX2[0-7] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
^ACUS48 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
^FNUS31 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*PFWFD1.*
^FNUS32 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*PFWFD2.*
@@ -149,9 +148,14 @@
^ACUS01 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
^ACUS02 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
^ACUS03 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
- ^WWUS01 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
- ^WWUS02 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
- ^WWUS03 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
+ ^FNUS2[1|2] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
+ ^FNUS28 KWNS (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
+ ^FNUS5[1-6] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
+ ^FNUS6[1-6] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
+ ^FNUS8[1-6] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
+ ^FNCA5[1-6] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
+ ^FNHW5[1-6] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
+ ^WWUS8[2-6] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
^WWUS20 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
^WWUS50 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*SEV[0-9].*
^WWUS60 .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*SEVSPC.*
@@ -191,6 +195,9 @@
^WSUS4[012] .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
^WSUK.. .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*
^WS[^U]... .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*
+ ^WUUS01 KWNS (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*
+ ^WUUS02 KWNS (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*
+ ^WUUS03 KWNS (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*
^FT.... .... (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).+
^...... KWBC (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*HSF.*
^...... PHFO (0[1-9]|[12][0-9]|3[01])([01][0-9]|2[0-3])([0-5][0-9]).*HSF.*
diff --git a/rpms/awips2.core/Installer.gfesuite-client/component.spec b/rpms/awips2.core/Installer.gfesuite-client/component.spec
index a9d83dcb64..d370dcd8a0 100644
--- a/rpms/awips2.core/Installer.gfesuite-client/component.spec
+++ b/rpms/awips2.core/Installer.gfesuite-client/component.spec
@@ -70,7 +70,10 @@ mkdir -p ${RPM_BUILD_ROOT}/awips2/GFESuite/products/ISC
if [ $? -ne 0 ]; then
exit 1
fi
-
+mkdir -p ${RPM_BUILD_ROOT}/awips2/GFESuite/products/ATBL
+if [ $? -ne 0 ]; then
+ exit 1
+fi
# Copy the profile.d scripts.
PROFILE_D_DIR="rpms/common/environment/awips2-gfesuite/profile.d"
@@ -97,4 +100,4 @@ rm -rf ${RPM_BUILD_ROOT}
%dir /awips2/GFESuite/exportgrids2
%defattr(644,awips,fxalpha,775)
%dir /awips2/GFESuite/products
-/awips2/GFESuite/products/*
\ No newline at end of file
+/awips2/GFESuite/products/*
diff --git a/rpms/awips2.core/Installer.gfesuite-server/component.spec b/rpms/awips2.core/Installer.gfesuite-server/component.spec
index fc79b78670..d06d039069 100644
--- a/rpms/awips2.core/Installer.gfesuite-server/component.spec
+++ b/rpms/awips2.core/Installer.gfesuite-server/component.spec
@@ -70,7 +70,10 @@ mkdir -p ${RPM_BUILD_ROOT}/awips2/GFESuite/products/ISC
if [ $? -ne 0 ]; then
exit 1
fi
-
+mkdir -p ${RPM_BUILD_ROOT}/awips2/GFESuite/products/ATBL
+if [ $? -ne 0 ]; then
+ exit 1
+fi
# Copy the profile.d scripts.
PROFILE_D_DIR="rpms/common/environment/awips2-gfesuite/profile.d"
@@ -101,4 +104,4 @@ rm -rf ${RPM_BUILD_ROOT}
%config(noreplace) /awips2/GFESuite/ServiceBackup/configuration/svcbu.properties
%defattr(644,awips,fxalpha,775)
%dir /awips2/GFESuite/products
-/awips2/GFESuite/products/*
\ No newline at end of file
+/awips2/GFESuite/products/*
diff --git a/rpms/build/i386/build.sh b/rpms/build/i386/build.sh
index 7b44d8b057..cb8d325319 100644
--- a/rpms/build/i386/build.sh
+++ b/rpms/build/i386/build.sh
@@ -362,10 +362,10 @@ fi
if [ "${1}" = "-edex" ]; then
#buildRPM "awips2"
- buildRPM "awips2-common-base"
- buildRPM "awips2-adapt-native"
- buildRPM "awips2-python-qpid"
- buildRPM "awips2-cli"
+ #buildRPM "awips2-common-base"
+ #buildRPM "awips2-adapt-native"
+ #buildRPM "awips2-python-qpid"
+ #buildRPM "awips2-cli"
buildRPM "awips2-gfesuite-client"
buildRPM "awips2-gfesuite-server"
buildEDEX
diff --git a/nativeLib/files.native/edex/data/hdf5/hydroapps/lib/native/linux32/library.empty.motif.so b/nativeLib/files.native/edex/data/hdf5/hydroapps/lib/native/linux32/library.empty.motif.so
deleted file mode 100644
index a026e3d168..0000000000
Binary files a/nativeLib/files.native/edex/data/hdf5/hydroapps/lib/native/linux32/library.empty.motif.so and /dev/null differ
diff --git a/ncep/gov.noaa.nws.ncep.common.dataplugin.geomag/src/gov/noaa/nws/ncep/common/dataplugin/geomag/GeoMagRecord.java b/ncep/gov.noaa.nws.ncep.common.dataplugin.geomag/src/gov/noaa/nws/ncep/common/dataplugin/geomag/GeoMagRecord.java
index c541ec70b0..631085f11a 100644
--- a/ncep/gov.noaa.nws.ncep.common.dataplugin.geomag/src/gov/noaa/nws/ncep/common/dataplugin/geomag/GeoMagRecord.java
+++ b/ncep/gov.noaa.nws.ncep.common.dataplugin.geomag/src/gov/noaa/nws/ncep/common/dataplugin/geomag/GeoMagRecord.java
@@ -1,7 +1,7 @@
package gov.noaa.nws.ncep.common.dataplugin.geomag;
-import java.util.Calendar;
-
+import javax.persistence.Access;
+import javax.persistence.AccessType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.SequenceGenerator;
@@ -18,23 +18,22 @@ import com.raytheon.uf.common.dataplugin.PluginDataObject;
import com.raytheon.uf.common.dataplugin.annotations.DataURI;
import com.raytheon.uf.common.dataplugin.persist.PersistablePluginDataObject;
import com.raytheon.uf.common.datastorage.IDataStore;
-import com.raytheon.uf.common.datastorage.records.ByteDataRecord;
import com.raytheon.uf.common.datastorage.records.FloatDataRecord;
import com.raytheon.uf.common.datastorage.records.IDataRecord;
-import com.raytheon.uf.common.datastorage.records.IntegerDataRecord;
import com.raytheon.uf.common.datastorage.records.LongDataRecord;
-import com.raytheon.uf.common.datastorage.records.StringDataRecord;
import com.raytheon.uf.common.serialization.annotations.DynamicSerialize;
import com.raytheon.uf.common.serialization.annotations.DynamicSerializeElement;
+
/**
- * Record implementation for geomag plugin.
+ * Record implementation for geomag plugin.
*
*
* SOFTWARE HISTORY
* Date Ticket# Engineer Description
* ------------ ---------- ---------------- --------------------------
* 03/27/2013 975 sgurung Initial creation.
* 05/26/2013 bhebbard Added SequenceGenerator annotation.
*
*
* @author sgurung
@@ -52,13 +51,13 @@ public class GeoMagRecord extends PersistablePluginDataObject {
private static final long serialVersionUID = 1L;
public static final String OBS_TIME = "OBS_TIME";
-
+
public static final String component1 = "component1";
-
+
public static final String component2 = "component2";
-
+
public static final String component3 = "component3";
-
+
public static final String component4 = "component4";
/**
@@ -83,43 +82,46 @@ public class GeoMagRecord extends PersistablePluginDataObject {
* report type
*/
@DataURI(position = 3)
- @Column
+ @Column
@DynamicSerializeElement
@XmlAttribute
private String reportType;
-
+
/**
* flag to indicate bad data point
*/
- /*@Column
- @DynamicSerializeElement
- @XmlAttribute
- private String badDataPoint;*/
-
+ /*
+ * @Column
+ *
+ * @DynamicSerializeElement
+ *
+ * @XmlAttribute private String badDataPoint;
+ */
+
/**
* Observation Date and Time for the minute values
*/
@Transient
private long[] obs_times;
-
+
/**
* H or X values
*/
@Transient
private float[] comp1_data;
-
+
/**
* D or Y values
*/
@Transient
private float[] comp2_data;
-
+
/**
* Z values
*/
@Transient
private float[] comp3_data;
-
+
/**
* F values
*/
@@ -157,7 +159,7 @@ public class GeoMagRecord extends PersistablePluginDataObject {
public void setStationCode(String stationCode) {
this.stationCode = stationCode;
}
-
+
/**
* @return the sourceId
*/
@@ -172,7 +174,7 @@ public class GeoMagRecord extends PersistablePluginDataObject {
public void setSourceId(int sourceId) {
this.sourceId = sourceId;
}
-
+
/**
* @return the reportType
*/
@@ -202,7 +204,7 @@ public class GeoMagRecord extends PersistablePluginDataObject {
public void setObsTimes(long[] obs_times) {
this.obs_times = obs_times;
}
-
+
/**
* @return the comp1_data
*/
@@ -217,7 +219,7 @@ public class GeoMagRecord extends PersistablePluginDataObject {
public void setComp1Data(float[] h_data) {
this.comp1_data = h_data;
}
-
+
/**
* @return the comp2_data
*/
@@ -232,7 +234,7 @@ public class GeoMagRecord extends PersistablePluginDataObject {
public void setComp2Data(float[] d_data) {
this.comp2_data = d_data;
}
-
+
/**
* @return the comp3_data
*/
@@ -247,7 +249,7 @@ public class GeoMagRecord extends PersistablePluginDataObject {
public void setComp3Data(float[] z_data) {
this.comp3_data = z_data;
}
-
+
/**
* @return the comp4_data
*/
@@ -262,37 +264,43 @@ public class GeoMagRecord extends PersistablePluginDataObject {
public void setComp4Data(float[] f_data) {
this.comp4_data = f_data;
}
-
+
@Override
public IDecoderGettable getDecoderGettable() {
return null;
}
public void retrieveFromDataStore(IDataStore dataStore) {
-
+
try {
IDataRecord[] dataRec = dataStore.retrieve(getDataURI());
- for (int i = 0; i < dataRec.length; i++) {
- if (dataRec[i].getName().equals(GeoMagRecord.component1)) {
- obs_times = (((LongDataRecord) dataRec[i]).getLongData());
- }
- if (dataRec[i].getName().equals(GeoMagRecord.component1)) {
- comp1_data = (((FloatDataRecord) dataRec[i]).getFloatData());
- }
- if (dataRec[i].getName().equals(GeoMagRecord.component2)) {
- comp2_data = (((FloatDataRecord) dataRec[i]).getFloatData());
- }
- if (dataRec[i].getName().equals(GeoMagRecord.component3)) {
- comp3_data = (((FloatDataRecord) dataRec[i]).getFloatData());
- }
- if (dataRec[i].getName().equals(GeoMagRecord.component4)) {
- comp4_data = (((FloatDataRecord) dataRec[i]).getFloatData());
- }
+ for (IDataRecord element : dataRec) {
+ if (element.getName().equals(GeoMagRecord.component1)) {
+ obs_times = (((LongDataRecord) element).getLongData());
+ }
+ if (element.getName().equals(GeoMagRecord.component1)) {
+ comp1_data = (((FloatDataRecord) element).getFloatData());
+ }
+ if (element.getName().equals(GeoMagRecord.component2)) {
+ comp2_data = (((FloatDataRecord) element).getFloatData());
+ }
+ if (element.getName().equals(GeoMagRecord.component3)) {
+ comp3_data = (((FloatDataRecord) element).getFloatData());
+ }
+ if (element.getName().equals(GeoMagRecord.component4)) {
+ comp4_data = (((FloatDataRecord) element).getFloatData());
+ }
}
} catch (Exception se) {
se.printStackTrace();
}
}
-
+
+ @Override
+ @Column
+ @Access(AccessType.PROPERTY)
+ public String getDataURI() {
+ return super.getDataURI();
+ }
}
@@ -18,23 +18,22 @@ import com.raytheon.uf.common.dataplugin.PluginDataObject;
* ------------ ---------- ---------------- --------------------------
* 03/27/2013 975 sgurung Initial creation.
- * 05/26/2013 bhebbard Added SequenceGenerator annotation.
+ * 05/26/2013 bhebbard Added SequenceGenerator annotation.
+ * 07/22/2013 1977 rjpeter Added getDataURI and annotations.
*
*